@@ -3,7 +3,7 @@ __license__ = "Apache-2.0"
 
 # do not change this line manually
 # this is managed by git tag and updated on every release
-__version__ = '0.4.5'
+__version__ = '0.4.10'
 
 # do not change this line manually
 # this is managed by proto/build-proto.sh and updated on every execution
@@ -59,6 +59,7 @@ __jina_env__ = ('JINA_ARRAY_QUANT',
                 'JINA_TEST_CONTAINER',
                 'JINA_TEST_GPU',
                 'JINA_TEST_PRETRAINED',
+                'JINA_TEST_FAISS',
                 'JINA_VCS_VERSION',
                 'JINA_VERSION',
                 'JINA_WARN_UNNAMED',
@@ -74,6 +75,7 @@ JINA_GLOBAL = SimpleNamespace()
 JINA_GLOBAL.imported = SimpleNamespace()
 JINA_GLOBAL.imported.executors = False
 JINA_GLOBAL.imported.drivers = False
+JINA_GLOBAL.imported.hub = False
 JINA_GLOBAL.stack = SimpleNamespace()
 JINA_GLOBAL.stack.id = random.randint(0, 10000)
 JINA_GLOBAL.logserver = SimpleNamespace()
@@ -91,7 +93,8 @@ def import_classes(namespace: str, targets=None,
     :param import_once: import everything only once, to avoid repeated import
     """
 
-    import os, sys
+    import os, sys, re
+    from .logging import default_logger
 
     if namespace == 'jina.executors':
         import_type = 'ExecutorType'
@@ -101,13 +104,23 @@ def import_classes(namespace: str, targets=None,
         import_type = 'DriverType'
         if import_once and JINA_GLOBAL.imported.drivers:
             return
+    elif namespace == 'jina.hub':
+        import_type = 'ExecutorType'
+        if import_once and JINA_GLOBAL.imported.hub:
+            return
     else:
         raise TypeError(f'namespace: {namespace} is unrecognized')
 
     from setuptools import find_packages
     import pkgutil
     from pkgutil import iter_modules
-    path = os.path.dirname(pkgutil.get_loader(namespace).path)
+
+    try:
+        path = os.path.dirname(pkgutil.get_loader(namespace).path)
+    except AttributeError:
+        if namespace == 'jina.hub':
+            default_logger.error(f'hub submodule is not initialized. Please try "git submodule update --init"')
+        return {}
 
     modules = set()
 
@@ -127,6 +140,10 @@ def import_classes(namespace: str, targets=None,
                 if not info.ispkg:
                     modules.add('.'.join([namespace, pkg, info.name]))
 
+    # filter
+    ignored_module_pattern = r'\.tests|\.api'
+    modules = {m for m in modules if not re.findall(ignored_module_pattern, m)}
+
     from collections import defaultdict
     load_stat = defaultdict(list)
     bad_imports = []
@@ -186,13 +203,14 @@ def import_classes(namespace: str, targets=None,
         print_load_table(load_stat)
     else:
         if bad_imports:
-            from .logging import default_logger
             default_logger.error(f'theses modules or classes can not be imported {bad_imports}')
 
     if namespace == 'jina.executors':
         JINA_GLOBAL.imported.executors = True
     elif namespace == 'jina.drivers':
         JINA_GLOBAL.imported.drivers = True
+    elif namespace == 'jina.hub':
+        JINA_GLOBAL.imported.hub = True
 
     return depend_tree
 
@@ -200,6 +218,7 @@ def import_classes(namespace: str, targets=None,
 # driver first, as executor may contain driver
 import_classes('jina.drivers', show_import_table=False, import_once=True)
 import_classes('jina.executors', show_import_table=False, import_once=True)
+import_classes('jina.hub', show_import_table=False, import_once=True)
 
 # manually install the default signal handler
 import signal
