@@ -5,7 +5,7 @@ import mimetypes
 import os
 import urllib.parse
 import urllib.request
-from typing import Dict, Any, Iterable, Tuple, Union, List, Callable
+from typing import Dict, Any, Iterable, Tuple
 
 import numpy as np
 
@@ -66,56 +66,43 @@ def array2pb(x: 'np.ndarray', quantize: str = None) -> 'jina_pb2.NdArray':
 
     blob.buffer = x.tobytes()
     blob.shape.extend(list(x.shape))
-    blob.dtype = x.dtype.name
+    blob.dtype = x.dtype.str
     return blob
 
 
-def extract_chunks(docs: Iterable['jina_pb2.Document'],
-                   chunks_iter_fn: Callable,
-                   filter_by: Union[Tuple[str], List[str]],
-                   embedding: bool) -> Tuple:
+def extract_docs(docs: Iterable['jina_pb2.Document'], embedding: bool) -> Tuple:
     """Iterate over a list of protobuf documents and extract chunk-level information from them
 
     :param docs: an iterable of protobuf documents
     :param embedding: an indicator of extracting embedding or not.
-                    If ``True`` then all chunk-level embedding are extracted.
-                    If ``False`` then ``text``, ``buffer``, ``blob`` info of each chunks are extracted
-    :param filter_by: a list of service names to wait
-    :return: A tuple of four pieces:
+                    If ``True`` then all doc-level embedding are extracted.
+                    If ``False`` then ``text``, ``buffer``, ``blob`` info of each doc are extracted
+    :return: A tuple of 3 pieces:
 
             - a numpy ndarray of extracted info
-            - the corresponding chunk references
-            - the doc_id list where the doc has no chunk, useful for debugging
-            - the chunk_id list where the chunk has no contents, useful for debugging
+            - the corresponding doc references
+            - the doc_id list where the doc has no contents, useful for debugging
     """
-    _contents = []
-    chunk_pts = []
-    no_chunk_docs = []
-    bad_chunk_ids = []
+    contents = []
+    docs_pts = []
+    bad_doc_ids = []
 
     if embedding:
-        _extract_fn = lambda c: c.embedding.buffer and pb2array(c.embedding)
+        _extract_fn = lambda doc: doc.embedding.buffer and pb2array(doc.embedding)
     else:
-        _extract_fn = lambda c: c.text or c.buffer or (c.blob and pb2array(c.blob))
+        _extract_fn = lambda doc: doc.text or doc.buffer or (doc.blob and pb2array(doc.blob))
 
-    for d in docs:
-        has_chunk = False
-        for c in chunks_iter_fn(d):
-            _c = _extract_fn(c)
-            if filter_by and (c.field_name not in filter_by):
-                continue
+    for doc in docs:
+        content = _extract_fn(doc)
 
-            if _c is not None:
-                _contents.append(_c)
-                chunk_pts.append(c)
-                has_chunk = True
-            else:
-                bad_chunk_ids.append((d.doc_id, c.chunk_id))
-        if not has_chunk:
-            no_chunk_docs.append(d.doc_id)
+        if content is not None:
+            contents.append(content)
+            docs_pts.append(doc)
+        else:
+            bad_doc_ids.append((doc.id, doc.parent_id))
 
-    contents = np.stack(_contents) if len(_contents) > 0 else None
-    return contents, chunk_pts, no_chunk_docs, bad_chunk_ids
+    contents = np.stack(contents) if contents else None
+    return contents, docs_pts, bad_doc_ids
 
 
 def routes2str(msg: 'jina_pb2.Message', flag_current: bool = False) -> str:
@@ -150,7 +137,10 @@ def pb_obj2dict(obj, keys: Iterable[str]) -> Dict[str, Any]:
     :param obj: a protobuf object
     :param keys: an iterable of keys for extraction
     """
-    return {k: getattr(obj, k) for k in keys if hasattr(obj, k)}
+    ret = {k: getattr(obj, k) for k in keys if hasattr(obj, k)}
+    if 'blob' in ret:
+        ret['blob'] = pb2array(obj.blob)
+    return ret
 
 
 def guess_mime(uri):
