@@ -25,14 +25,14 @@ To use these enums in YAML config, following the example below:
 .. code-block:: yaml
 
       chunk_idx:
-        yaml_path: index/chunk.yml
-        replicas: $REPLICAS
+        uses: index/chunk.yml
+        parallel: $PARALLEL
         separated_workspace: true
-        replicas_type: !PollingType ANY
+        parallel_type: !PollingType ANY
         # or
-        replicas_type: ANY
+        parallel_type: ANY
         # or
-        replicas_type: any
+        parallel_type: any
 """
 
 from enum import IntEnum, EnumMeta
